import bpy
import os
import time
import webbrowser
from bpy.props import FloatProperty
from . import functions


class ALPHATREE_OT_set_up_scene(bpy.types.Operator):
    """Set up scene for rendering"""
    bl_label = "Set up scene"
    bl_idname = "alpha_tree.set_up_scene"
    bl_description = "Set up scene for rendering"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {"REGISTER", "UNDO"}

    def execute(self, context):

        functions.setup_scene(self, context)

        return {"FINISHED"}


class ALPHATREE_OT_set_up_tree(bpy.types.Operator):
    """Set up tree for rendering"""
    bl_label = "Set up tree"
    bl_idname = "alpha_tree.set_up_tree"
    bl_description = "Set up tree for rendering"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {"REGISTER", "UNDO"}

    def execute(self, context):

        if not bpy.context.selected_objects:
            self.report({"WARNING"}, "No objects selected")
            return {"CANCELLED"}

        functions.scale_to_height()
        functions.set_render_border(context)
        functions.transparent_normal(self,context)

        return {"FINISHED"}

class ALPHATREE_OT_render_maps(bpy.types.Operator):
    """render all maps"""
    bl_label = "Render maps"
    bl_idname = "alpha_tree.render_maps"
    bl_description = "render all maps"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {"REGISTER", "UNDO"}

    def execute(self, context):

        if not bpy.context.selected_objects:
            self.report({"WARNING"}, "No objects selected")
            return {"CANCELLED"}

        functions.render_maps(self, context)

        return {"FINISHED"}


class ALPHATREE_OT_open_folder(bpy.types.Operator):
    """open the renders folder"""
    bl_label = "Open renders folder"
    bl_idname = "alpha_tree.open_folder"
    bl_description = "Open renders folder"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {"REGISTER", "UNDO"}

    def execute(self, context):

        at = bpy.context.scene.alpha_trees
        if at.open_leaf_folder:
            script_path = os.path.dirname(os.path.abspath(__file__)) + "\\maps\\leaf_maps\\"
            path = bpy.path.abspath(script_path)
        else:
            path = bpy.path.abspath(at.render_filepath)
        webbrowser.open('file:///' + path)
        return {"FINISHED"}


class ALPHATREE_OT_execute_all(bpy.types.Operator):
    """Execute all operators"""
    bl_label = "Execute all"
    bl_idname = "alpha_tree.execute_all"
    bl_description = "Execute all operators"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {"REGISTER", "UNDO"}

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        cscene = scene.cycles
        layout.scale_y = 1.3
        layout.prop(cscene, "samples", text="samples (50 max.)")

    def invoke(self, context, event):
        return context.window_manager.invoke_props_dialog(self)

    def execute(self, context):

        if not bpy.context.selected_objects:
            self.report({"WARNING"}, "No objects selected")
            return {"CANCELLED"}

        start = time.time()
        at = bpy.context.scene.alpha_trees

        print("Scaling object")
        functions.scale_to_height()
        functions.set_render_border(context)
        print("Rendering normal image")
        functions.transparent_normal(self,context)
        print("Rendering maps")
        functions.render_maps(self, context)
        if at.open_renders_folder:
            print("Opening folder")
            bpy.ops.alpha_tree.open_folder()

        total_time = round(time.time() - start, 2)

        print(f"Done in {total_time} seconds")

        return {"FINISHED"}


classes = (
    ALPHATREE_OT_set_up_scene,
    ALPHATREE_OT_execute_all,
    ALPHATREE_OT_open_folder,
    ALPHATREE_OT_render_maps,
    ALPHATREE_OT_set_up_tree,
)


def register():
    for cls in classes:
        bpy.utils.register_class(cls)


def unregister():
    for cls in classes:
        bpy.utils.unregister_class(cls)
