import bpy
from . import functions, operators, settings

class AlphaTreesPrefs(bpy.types.AddonPreferences):
    bl_idname = __package__

    show_extra_operators: bpy.props.BoolProperty(
        name="Show extra operators",
        default = True,
    )

    def draw(self, context):
        layout = self.layout
        layout.prop(self, "show_extra_operators")

class ALPHATREE_PT_panel(bpy.types.Panel):
    """Creates a Panel in the object Tools panel"""
    bl_space_type = "VIEW_3D"
    #bl_context = "objectmode"
    bl_region_type = "UI"
    bl_label = "Alpa tree generator"
    bl_category = "Alpha tree generator"

    def draw_header(self, context):
        layout = self.layout
        at = bpy.context.scene.alpha_trees
        layout.prop(at, "show_panel", text="")

    def draw(self, context):
        prefs = context.preferences.addons[__package__].preferences
        at = bpy.context.scene.alpha_trees
        layout = self.layout
        if at.show_panel:
            if context.scene.name == "alpha_trees_scene":
                #row = layout.row()
                #row.scale_y = 1.6
                #row.scale_x = 1.13
                #row.operator("alpha_tree.set_up_scene", icon = "TOOL_SETTINGS")

                if prefs.show_extra_operators:
                    functions.dropdown_operator(
                        layout,
                        context,
                        name="  Alpha Trees",
                        operators=["alpha_tree.set_up_tree","alpha_tree.render_maps", "alpha_tree.open_folder", ],
                        icons=["SORT_DESC","RESTRICT_RENDER_OFF", "FILEBROWSER", ],
                        operator_booleans=[at.show_setup_tree_settings,at.show_render_settings, at.show_open_folder_settings, ],
                        operator_boolean_strings=["show_setup_tree_settings", "show_render_settings", "show_open_folder_settings", ],
                        operator_settings=[["z_dimension", "scale_padding", "border_padding"], [
                            "resolution", "render_filepath", "diff_render", "nor_render", "mask_render", "overwrite", "remove_extra_masks", ], ["open_leaf_folder"]],
                        setttings_toggle=[[], [False, False,True, True, True, False, False], []]
                    )
                
                # else:
                #     row = layout.row()
                #     row.alignment = "RIGHT"
                #     row.prop(at, "show_info", text="", icon="INFO", emboss=False)
                #     col = layout.column()
                #     col.scale_y = 0.8
                #     if at.show_info:
                #         functions.draw_info(col)

                functions.operator_settings(
                    layout,
                    context,
                    bool=at.show_exec_all_settings,
                    bool_string="show_exec_all_settings",
                    operator="alpha_tree.execute_all",
                    settings=[["Scale to camera"], "z_dimension", "scale_padding", ["Render border"], "border_padding", ["Rendering"],
                            "resolution", "render_filepath", "diff_render", "nor_render", "mask_render", "remove_extra_masks", "overwrite", ["Open renders folder"], "open_renders_folder"],
                    settings_toggle = [False,False,False,False,False,False,False,False,False,False,False,True,True,True,False,False,False,False,],
                    icon="DRIVER",
                    scale=1.75)
            else:
                row = layout.row()
                row.scale_y = 1.6
                row.scale_x = 1.13
                row.operator("alpha_tree.set_up_scene", icon = "TOOL_SETTINGS")


def register():
    bpy.utils.register_class(ALPHATREE_PT_panel)
    bpy.utils.register_class(AlphaTreesPrefs)


def unregister():
    bpy.utils.unregister_class(ALPHATREE_PT_panel)
    bpy.utils.unregister_class(AlphaTreesPrefs)
